@@ -120,7 +120,7 @@ const char* ffGPUDetectByDirectX(FF_MAYBE_UNUSED const FFGPUOptions* options, FF
                     .memory = options->driverSpecific ? &gpu->dedicated : NULL,
                     .coreCount = options->driverSpecific ? (uint32_t*) &gpu->coreCount : NULL,
                     .type = &gpu->type,
-                    .frequency = &gpu->frequency,
+                    .frequency = options->driverSpecific ? &gpu->frequency : NULL,
                 }, "/usr/lib/wsl/lib/libnvidia-ml.so");
             }
         }
